@@ -491,4 +491,10 @@ GmmLib::PlatformInfoGen9::PlatformInfoGen9(PLATFORM &Platform)
     }
 
     Data.HiZPixelsPerByte = 2;
+
+    Data.ReconMaxHeight = Data.Texture2DSurface.MaxHeight; // Reconstructed surfaces require more height and width for higher resolutions.
+    Data.ReconMaxWidth  = Data.Texture2DSurface.MaxWidth;
+
+    Data.NoOfBitsSupported                = 39;
+    Data.HighestAcceptablePhysicalAddress = GFX_MASK_LARGE(0, 38);
 }
