@@ -59,7 +59,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                 CreateParams.Flags.Info.TiledY = true;
 
                 // Pre-Gen11 Planar
-                if(GmmIsPlanar(CreateParams.Format))
+                if(GmmIsPlanar(CreateParams.Format) && (GFX_GET_CURRENT_RENDERCORE(pGmmGlobalContext->GetPlatformInfo().Platform) < IGFX_GEN11_CORE))
                 {
                     CreateParams.Flags.Info.TiledX = true;
                 }
@@ -116,14 +116,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
         return false;
     }
 
-    if((GFX_GET_CURRENT_RENDERCORE(pGmmGlobalContext->GetPlatformInfo().Platform) <= IGFX_GEN11_CORE))
-    {
-        if(Surf.Flags.Gpu.MCS)
-        {
-            Surf.Flags.Gpu.CCS = Surf.Flags.Gpu.MCS;
-        }
-        Surf.Flags.Info.RenderCompressed = Surf.Flags.Info.MediaCompressed = 0;
-    }
+    pGmmGlobalContext->GetPlatformInfoObj()->SetCCSFlag(this->GetResFlags());
 
     // Moderate down displayable flags if input parameters are not conducive.
     // Reject non displayable tiling modes
@@ -154,6 +147,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
         {
             //GMM_ASSERTDPF(Surf.Flags.Gpu.HiZ, "Lossless Z compression supported when Depth+HiZ+CCS is unified");
             AuxSecSurf                           = Surf;
+            AuxSecSurf.Type                      = AuxSecSurf.Type;
             Surf.Flags.Gpu.HiZ                   = 0; //Its depth buffer, so clear HiZ
             AuxSecSurf.Flags.Gpu.HiZ             = 0;
             AuxSurf.Flags.Gpu.IndirectClearColor = 0; //Clear Depth flags from HiZ, contained with separate/legacy HiZ when Depth isn't compressible.
@@ -170,17 +164,24 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                 return false;
             }
             Surf.Flags.Gpu.CCS = 1;
+            AuxSurf.Type       = AuxSurf.Type;
         }
         else if(Surf.MSAA.NumSamples > 1 && Surf.Flags.Gpu.CCS) //MSAA+MCS+CCS
         {
             GMM_ASSERTDPF(Surf.Flags.Gpu.MCS, "Lossless MSAA supported when MSAA+MCS+CCS is unified");
             AuxSecSurf                          = Surf;
+            AuxSecSurf.Type                     = AuxSecSurf.Type;
             AuxSecSurf.Flags.Gpu.MCS            = 0;
             AuxSurf.Flags.Gpu.CCS               = 0;
             AuxSurf.Flags.Info.RenderCompressed = AuxSurf.Flags.Info.MediaCompressed = 0;
         }
+        else if(Surf.Flags.Gpu.CCS)
+        {
+            AuxSurf.Type = AuxSurf.Type;
+        }
 
-        if(GMM_SUCCESS != pTextureCalc->PreProcessTexSpecialCases(&AuxSurf))
+        if(AuxSurf.Type != RESOURCE_INVALID &&
+           GMM_SUCCESS != pTextureCalc->PreProcessTexSpecialCases(&AuxSurf))
         {
             return false;
         }
@@ -221,8 +222,10 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
 {
     __GMM_BUFFER_TYPE              Restrictions             = {0};
     const __GMM_PLATFORM_RESOURCE *pPlatformResource        = NULL;
+    GMM_TEXTURE_CALC *             pTextureCalc             = NULL;
     bool                           AllowMaxWidthViolations  = false;
     bool                           AllowMaxHeightViolations = false;
+    uint8_t                        Status                   = 0;
 
     GMM_DPF_ENTER;
 
@@ -270,6 +273,7 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
 #endif
 
     pPlatformResource = GMM_OVERRIDE_PLATFORM_INFO(&Surf);
+    pTextureCalc      = GMM_OVERRIDE_TEXTURE_CALC(&Surf);
 
     __GMM_ASSERT(!(
     Surf.Flags.Gpu.Query &&
@@ -350,6 +354,13 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
         goto ERROR_CASE;
     }
 
+    if((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) > IGFX_GEN11_CORE) &&
+       Surf.Flags.Info.TiledW)
+    {
+        GMM_ASSERTDPF(0, "Flag not supported on this platform.");
+        goto ERROR_CASE;
+    }
+
     if((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) < IGFX_GEN9_CORE) &&
 #if(_DEBUG || _RELEASE_INTERNAL)
        !pGmmGlobalContext->GetWaTable().WaDisregardPlatformChecks &&
@@ -360,11 +371,8 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
         goto ERROR_CASE;
     }
 
-    if(Surf.Flags.Gpu.MMC && //For Media Memory Compression --
-       ((!(GMM_IS_4KB_TILE(Surf.Flags) ||  GMM_IS_64KB_TILE(Surf.Flags)) &&
-         (GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) <= IGFX_GEN11_CORE)) ||
-        (GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) <= IGFX_GEN11_CORE &&
-         Surf.ArraySize > GMM_MAX_MMC_INDEX)))
+    //For Media Memory Compression --
+    if((Status = pGmmGlobalContext->GetPlatformInfoObj()->ValidateMMC(Surf)) == 0)
     {
         GMM_ASSERTDPF(0, "Invalid flag or array size!");
         goto ERROR_CASE;
@@ -397,7 +405,7 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
         }
     }
 
-    GetRestrictions(Restrictions);
+    pTextureCalc->GetResRestrictions(&Surf, Restrictions);
 
     // Check array size to make sure it meets HW limits
     if((Surf.ArraySize > Restrictions.MaxArraySize) &&
@@ -513,14 +521,7 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
     // CCS Restrictions
     if(Surf.Flags.Gpu.CCS)
     {
-        if(!(                                                           //--- Legitimate CCS Case ----------------------------------------
-           ((Surf.Type >= RESOURCE_2D && Surf.Type <= RESOURCE_BUFFER) && //Not supported: 1D; Supported: Buffer, 2D, 3D, cube, Arrays, mip-maps, MSAA, Depth/Stencil
-            (Surf.Type <= RESOURCE_CUBE &&
-              GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) >= IGFX_GEN8_CORE &&
-              GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) <= IGFX_GEN11_CORE)
-             ) ||
-           ((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) < IGFX_GEN8_CORE) &&
-            Surf.Type == RESOURCE_2D && Surf.MaxLod == 0)))
+        if((Status = pGmmGlobalContext->GetPlatformInfoObj()->ValidateCCS(Surf)) == 0)
         {
             GMM_ASSERTDPF(0, "Invalid CCS usage!");
             goto ERROR_CASE;
@@ -534,11 +535,7 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
     }
 
     // UnifiedAuxSurface Restrictions
-    if((Surf.Flags.Gpu.UnifiedAuxSurface) &&
-       !( //--- Legitimate UnifiedAuxSurface Case ------------------------------------------
-       Surf.Flags.Gpu.CCS &&
-       (Surf.MSAA.NumSamples <= 1 && (Surf.Flags.Gpu.RenderTarget || Surf.Flags.Gpu.Texture))
-       ))
+    if((Status = pGmmGlobalContext->GetPlatformInfoObj()->ValidateUnifiedAuxSurface(Surf)) == 0)
     {
         GMM_ASSERTDPF(0, "Invalid UnifiedAuxSurface usage!");
         goto ERROR_CASE;
@@ -547,9 +544,10 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::ValidateParams()
     // IndirectClearColor Restrictions
     if((Surf.Flags.Gpu.IndirectClearColor) &&
        !( //--- Legitimate IndirectClearColor Case ------------------------------------------
-       (GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) >= IGFX_GEN9_CORE) &&
-        Surf.Flags.Gpu.UnifiedAuxSurface
-       ))
+       ((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) >= IGFX_GEN9_CORE) &&
+        Surf.Flags.Gpu.UnifiedAuxSurface) ||
+       ((GFX_GET_CURRENT_RENDERCORE(pPlatformResource->Platform) > IGFX_GEN11_CORE) &&
+        (Surf.Flags.Gpu.HiZ || Surf.Flags.Gpu.SeparateStencil))))
     {
         GMM_ASSERTDPF(0, "Invalid IndirectClearColor usage!");
         goto ERROR_CASE;
@@ -685,6 +683,7 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::GetDisplayCompressionSupport(
             case GMM_FORMAT_B10G10R10A2_UINT:
             case GMM_FORMAT_B10G10R10A2_UNORM_SRGB:
             case GMM_FORMAT_B10G10R10A2_USCALED:
+            case GMM_FORMAT_R10G10B10_FLOAT_A2_UNORM:
             case GMM_FORMAT_R10G10B10_SNORM_A2_UNORM:
             case GMM_FORMAT_R10G10B10A2_SINT:
             case GMM_FORMAT_R10G10B10A2_SNORM:
@@ -714,19 +713,10 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::GetDisplayCompressionSupport(
                 break;
         }
 
-        bool IsRenderCompressed = false;
-        bool IsMediaCompressed  = false;
-
-        if(IsSupportedRGB32_8_8_8_8 || //RGB32 8 : 8 : 8 : 8
-            (GFX_GET_CURRENT_PRODUCT(pGmmGlobalContext->GetPlatformInfo().Platform) == IGFX_ICELAKE &&
-             IsSupportedRGB64_16_16_16_16) || //RGB64 16:16 : 16 : 16 FP16
-            (GFX_GET_CURRENT_DISPLAYCORE(pGmmGlobalContext->GetPlatformInfo().Platform) >= IGFX_GEN10_CORE &&
-            IsSupportedRGB32_2_10_10_10)) //RGB32 2 : 10 : 10 : 10))
-        {
-            IsRenderCompressed = true;
-        }
-
-        ComprSupported = IsRenderCompressed || IsMediaCompressed;
+        //Check fmt is display decompressible
+        ComprSupported = pGmmGlobalContext->GetPlatformInfoObj()->CheckFmtDisplayDecompressible(Surf, IsSupportedRGB64_16_16_16_16,
+                                                                                                IsSupportedRGB32_8_8_8_8, IsSupportedRGB32_2_10_10_10,
+                                                                                                IsSupportedMediaFormats);
     }
 
     return ComprSupported;
@@ -756,4 +746,4 @@ uint8_t GMM_STDCALL GmmLib::GmmResourceInfoCommon::GetDisplayFastClearSupport()
     }
 
     return FCSupported;
-}
\ No newline at end of file
+}
