@@ -445,11 +445,8 @@ GMM_STATUS GmmLib::GmmTextureCalc::FillTexPitchAndSize(GMM_TEXTURE_INFO * pTexIn
                                      pBufferType->RenderPitchAlignment);
 
         // Media Memory Compression : Allocate one memory tile wider than is required...
-        if(pTexInfo->Flags.Gpu.MMC && !pTexInfo->Flags.Gpu.UnifiedAuxSurface && GFX_GET_CURRENT_RENDERCORE(pPlatform->Platform) <= IGFX_GEN11_CORE)
-        {
-            WidthBytesRender += pPlatform->TileInfo[pTexInfo->TileMode].LogicalTileWidth;
-            WidthBytesPhysical = WidthBytesLock = WidthBytesRender;
-        }
+        pGmmGlobalContext->GetTextureCalc()->AllocateOneTileThanRequied(pTexInfo, WidthBytesRender,
+                                                                        WidthBytesPhysical, WidthBytesLock);
 
         // check if locking a particular suface need to be power 2 or not
         if(pBufferType->NeedPow2LockAlignment)
@@ -983,11 +980,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
     __GMM_ASSERTPTR(pTexInfo, GMM_ERROR);
     __GMM_ASSERTPTR(pRestrictions, GMM_ERROR);
     __GMM_ASSERT(!pTexInfo->Flags.Info.TiledW);
-    // Client should always give us linear-fallback option for planar surfaces,
-    // except for MMC surfaces, which are TileY.
-    //__GMM_ASSERT(pTexInfo->Flags.Info.Linear || pTexInfo->Flags.Gpu.MMC);
-    pTexInfo->Flags.Info.Linear = 1;
-    pTexInfo->TileMode          = TILE_NONE;
+    pTexInfo->TileMode = TILE_NONE;
 
     const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
 
@@ -1025,10 +1018,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
 
                 Height = YHeight + 2 * VHeight; // One VHeight for V and one for U.
 
-                FillTexPlanar_SetTilingBasedOnRequiredAlignment(
-                pTexInfo,
-                YHeight, true,  // <-- YHeight alignment needed (so U is properly aligned).
-                VHeight, true); // <-- VHeight alignment needed (so V is properly aligned).
+                pTexInfo->OffsetInfo.Plane.NoOfPlanes = 3;
 
                 break;
             }
@@ -1046,10 +1036,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
 
                 Height = YHeight + 2 * VHeight;
 
-                FillTexPlanar_SetTilingBasedOnRequiredAlignment(
-                pTexInfo,
-                YHeight, true,  // <-- YHeight alignment needed (so U is properly aligned).
-                VHeight, true); // <-- VHeight alignment needed (so V is properly aligned).
+                pTexInfo->OffsetInfo.Plane.NoOfPlanes = 3;
 
                 break;
             }
@@ -1104,10 +1091,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
 
                 Height = YHeight + 2 * VHeight;
 
-                FillTexPlanar_SetTilingBasedOnRequiredAlignment(
-                pTexInfo,
-                YHeight, true,  // <-- YHeight alignment needed (so U is properly aligned).
-                YHeight, true); // <-- VHeight alignment needed (so V is properly aligned).
+                pTexInfo->OffsetInfo.Plane.NoOfPlanes = 3;
 
                 break;
             }
@@ -1128,11 +1112,6 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
 
             Height = YHeight + VHeight;
 
-            FillTexPlanar_SetTilingBasedOnRequiredAlignment(
-            pTexInfo,
-            YHeight, true, // <-- YHeight alignment needed (so U/V are properly aligned, vertically).
-            0, false);     // <-- VHeight alignment NOT needed (since U/V aren't on top of eachother).
-
             // With SURFACE_STATE.XOffset support, the U-V interface has
             // much lighter restrictions--which will be naturally met by
             // surface pitch restrictions (i.e. dividing an IMC2/4 pitch
@@ -1141,7 +1120,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
 
             // Not technically UV packed but sizing works out the same
             // if the resource is std swizzled
-            UVPacked = pTexInfo->Flags.Info.StdSwizzle ? true : false;
+            UVPacked                              = true;
+            pTexInfo->OffsetInfo.Plane.NoOfPlanes = 2;
 
             break;
         }
@@ -1158,7 +1138,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
             // YYYYYYYY
             // YYYYYYYY
             // [UV-Packing]
-
+            YHeight = GFX_ALIGN(pTexInfo->BaseHeight, __GMM_EVEN_ROW);
             if((pTexInfo->Format == GMM_FORMAT_NV12) ||
                (pTexInfo->Format == GMM_FORMAT_NV21) ||
                (pTexInfo->Format == GMM_FORMAT_P010) ||
@@ -1182,11 +1162,6 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
                (pTexInfo->Format == GMM_FORMAT_P208))
             {
                 WidthBytesPhysical = GFX_ALIGN(WidthBytesPhysical, 2); // If odd YWidth, pitch bumps-up to fit rounded-up U/V planes.
-
-                FillTexPlanar_SetTilingBasedOnRequiredAlignment(
-                pTexInfo,
-                YHeight, true, // <-- YHeight alignment needed (so UV is properly aligned).
-                0, false);     // <-- VHeight alignment NOT needed (since U/V aren't on top of eachother).
             }
             else //if(pTexInfo->Format == GMM_FORMAT_NV11)
             {
@@ -1198,8 +1173,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
                 pTexInfo->Flags.Info.Linear  = 1;
             }
 
-            UVPacked = true;
-
+            UVPacked                              = true;
+            pTexInfo->OffsetInfo.Plane.NoOfPlanes = 2;
             break;
         }
         case GMM_FORMAT_I420: // IYUV & I420: are identical to YV12 except,
@@ -1242,12 +1217,12 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
             Height = GFX_CEIL_DIV(YSize + UVSize, WidthBytesPhysical);
 
             // Tiling not supported, since YPitch != UVPitch...
-            pTexInfo->Flags.Info.TiledY  = 0;
-            pTexInfo->Flags.Info.TiledYf = 0;
-            pTexInfo->Flags.Info.TiledYs = 0;
-            pTexInfo->Flags.Info.TiledX  = 0;
-            pTexInfo->Flags.Info.Linear  = 1;
-
+            pTexInfo->Flags.Info.TiledY           = 0;
+            pTexInfo->Flags.Info.TiledYf          = 0;
+            pTexInfo->Flags.Info.TiledYs          = 0;
+            pTexInfo->Flags.Info.TiledX           = 0;
+            pTexInfo->Flags.Info.Linear           = 1;
+            pTexInfo->OffsetInfo.Plane.NoOfPlanes = 1;
             break;
         }
         default:
@@ -1262,8 +1237,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
 
     SetTileMode(pTexInfo);
 
-    // If the Surface has Odd height dimension, we will fall back to Linear Format.
-    // If MMC is enabled, disable MMC during such cases.
+    // MMC is not supported for linear formats.
     if(pTexInfo->Flags.Gpu.MMC)
     {
         if(!(pTexInfo->Flags.Info.TiledY || pTexInfo->Flags.Info.TiledYf || pTexInfo->Flags.Info.TiledYs))
@@ -1301,19 +1275,20 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
         pRestrictions->RenderPitchAlignment <<= LShift;
     }
 
-    // For std swizzled and UV packed tile Ys/Yf cases, the planes
-    // must be tile-boundary aligned. Actual alignment is handled
-    // in FillPlanarOffsetAddress, but height and width must
-    // be adjusted for correct size calculation
-    if((pTexInfo->Flags.Info.TiledYs || pTexInfo->Flags.Info.TiledYf) &&
-       (pTexInfo->Flags.Info.StdSwizzle || UVPacked))
+    // For Tiled Planar surfaces, the planes must be tile-boundary aligned.
+    // Actual alignment is handled in FillPlanarOffsetAddress, but height
+    // and width must be adjusted for correct size calculation
+    if(GMM_IS_TILED(pPlatform->TileInfo[pTexInfo->TileMode]))
     {
         uint32_t TileHeight = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileHeight;
         uint32_t TileWidth  = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileWidth;
 
+        pTexInfo->OffsetInfo.Plane.IsTileAlignedPlanes = true;
+
         Height = GFX_ALIGN(YHeight, TileHeight) + (GFX_ALIGN(VHeight, TileHeight) * (UVPacked ? 1 : 2));
 
-        if(UVPacked)
+        if(pTexInfo->Format == GMM_FORMAT_IMC2 || // IMC2, IMC4 needs even tile columns
+           pTexInfo->Format == GMM_FORMAT_IMC4)
         {
             // If the UV planes are packed then the surface pitch must be
             // padded out so that the tile-aligned UV data will fit.
@@ -1326,9 +1301,24 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::FillTexPlanar(GMM_TEXTURE_INFO *
             }
         }
 
-        pTexInfo->Flags.Info.RedecribedPlanes = 1;
+        if(pTexInfo->Flags.Info.TiledYs || pTexInfo->Flags.Info.TiledYf)
+        {
+            pTexInfo->Flags.Info.RedecribedPlanes = true;
+        }
     }
 
+    //Special case LKF MMC compressed surfaces
+    if(pTexInfo->Flags.Gpu.MMC &&
+       pTexInfo->Flags.Gpu.UnifiedAuxSurface &&
+       pTexInfo->Flags.Info.TiledY)
+    {
+        uint32_t TileHeight = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileHeight;
+        uint32_t TileWidth  = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileWidth;
+
+        Height = GFX_ALIGN(YHeight, TileHeight) + GFX_ALIGN(VHeight, TileHeight);
+    }
+
+    // Vary wide planar tiled planar formats do not support MMC pre gen11. All formats do not support
     // MMC above 16k bytes wide, while Yf NV12 does not support above 8k - 128 bytes.
     if((GFX_GET_CURRENT_RENDERCORE(pPlatform->Platform) <= IGFX_GEN10_CORE) &&
        (pTexInfo->Flags.Info.TiledY || pTexInfo->Flags.Info.TiledYf || pTexInfo->Flags.Info.TiledYs))
@@ -1442,3 +1432,163 @@ GMM_STATUS GmmLib::GmmTextureCalc::FillTexBlockMem(GMM_TEXTURE_INFO * pTexInfo,
     GMM_DPF_EXIT;
     return (Status);
 }
+
+
+/////////////////////////////////////////////////////////////////////////////////////
+/// This function does any special-case conversion from client-provided pseudo creation
+/// parameters to actual parameters for CCS.
+///
+/// @param[in]  pTexInfo: Reference to ::GMM_TEXTURE_INFO
+///
+///  @return     ::GMM_STATUS
+/////////////////////////////////////////////////////////////////////////////////////
+GMM_STATUS GMM_STDCALL GmmLib::GmmTextureCalc::MSAACCSUsage(GMM_TEXTURE_INFO *pTexInfo)
+{
+    GMM_STATUS Status = GMM_SUCCESS;
+    //const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
+
+    if(pTexInfo->MSAA.NumSamples > 1) // CCS for MSAA Compression
+    {
+        Status = MSAACompression(pTexInfo);
+    }
+    else // Non-MSAA CCS Use (i.e. Render Target Fast Clear)
+    {
+        if(!pTexInfo->Flags.Info.TiledW &&
+           ((!pTexInfo->Flags.Info.Linear) ||
+            (GMM_IS_4KB_TILE(pTexInfo->Flags) || GMM_IS_64KB_TILE(pTexInfo->Flags) ||
+             (pTexInfo->Type == RESOURCE_BUFFER && pTexInfo->Flags.Info.Linear))) && //!Yf - deprecate Yf
+           ((pTexInfo->MaxLod == 0) &&
+            (pTexInfo->ArraySize <= 1)) &&
+           (((pTexInfo->BitsPerPixel == 32) ||
+             (pTexInfo->BitsPerPixel == 64) ||
+             (pTexInfo->BitsPerPixel == 128))))
+        {
+            // For non-MSAA CCS usage, the four tables of
+            // requirements:
+            // (1) RT Alignment (GMM Don't Care: Occurs Naturally)
+            // (2) ClearRect Alignment
+            // (3) ClearRect Scaling (GMM Don't Care: GHAL3D Matter)
+            // (4) Non-MSAA CCS Sizing
+
+            // Gen8+:
+            // Since mip-mapped and arrayed surfaces are supported, we
+            // deal with alignment later at per mip level. Here, we set
+            // tiling type only. TileX is not supported on Gen9+.
+            // Pre-Gen8:
+            // (!) For all the above, there are separate entries for
+            // 32/64/128bpp--and then deals with PIXEL widths--Here,
+            // though, we will unify by considering 8bpp table entries
+            // (unlisted--i.e. do the math)--and deal with BYTE widths.
+
+            // (1) RT Alignment -- The surface width and height don't
+            // need to be padded to RT CL granularity. On HSW, all tiled
+            // RT's will have appropriate alignment (given 4KB surface
+            // base and no mip-map support) and appropriate padding
+            // (due to tile padding). On BDW+, GMM uses H/VALIGN that
+            // will guarantee the MCS RT alignment for all subresources.
+
+            // (2) ClearRect Alignment -- I.e. FastClears must be done
+            // with certain granularity:
+            //  TileY:  512 Bytes x 128 Lines
+            //  TileX: 1024 Bytes x  64 Lines
+            // So a CCS must be sized to match that granularity (though
+            // the RT itself need not be fully padded to that
+            // granularity to use FastClear).
+
+            // (4) Non-MSAA CCS Sizing -- CCS sizing is based on the
+            // size of the FastClear (with granularity padding) for the
+            // paired RT. CCS's (byte widths and heights) are scaled
+            // down from their RT's by:
+            //  TileY: 32 x 32
+            //  TileX: 64 x 16
+
+            // ### Example #############################################
+            // RT:         800x600, 32bpp, TileY
+            // 8bpp:      3200x600
+            // FastClear: 3584x640 (for TileY FastClear Granularity of 512x128)
+            // CCS:       112x20 (for TileY RT:CCS Sizing Downscale of 32x32)
+
+            uint32_t AlignmentFactor = pGmmGlobalContext->GetWaTable().WaDoubleFastClearWidthAlignment ? 2 : 1;
+
+            pTexInfo->BaseWidth    = pTexInfo->BaseWidth * pTexInfo->BitsPerPixel / 8;
+            pTexInfo->BitsPerPixel = 8;
+            pTexInfo->Format       = GMM_FORMAT_R8_UINT;
+
+            if(GMM_IS_4KB_TILE(pTexInfo->Flags)) //-------- Fast Clear Granularity
+            {                                    //                       /--- RT:CCS Sizing Downscale
+                pTexInfo->BaseWidth  = GFX_ALIGN(pTexInfo->BaseWidth, 512 * AlignmentFactor) / 32;
+                pTexInfo->BaseHeight = GFX_ALIGN(pTexInfo->BaseHeight, 128) / 32;
+            }
+            else //if(pTexInfo->Flags.Info.TiledX)
+            {
+                pTexInfo->BaseWidth  = GFX_ALIGN(pTexInfo->BaseWidth, 1024 * AlignmentFactor) / 64;
+                pTexInfo->BaseHeight = GFX_ALIGN(pTexInfo->BaseHeight, 64) / 16;
+            }
+        }
+        else
+        {
+            GMM_ASSERTDPF(0, "Illegal CCS creation parameters!");
+            Status = GMM_ERROR;
+        }
+    }
+    return Status;
+}
+
+/////////////////////////////////////////////////////////////////////////////////////
+/// This function does any special-case conversion from client-provided pseudo creation
+/// parameters to actual parameters for CCS for MSAA Compression.
+///
+/// @param[in]  pTexInfo: Reference to ::GMM_TEXTURE_INFO
+///
+///  @return     ::GMM_STATUS
+/////////////////////////////////////////////////////////////////////////////////////
+GMM_STATUS GmmLib::GmmTextureCalc::MSAACompression(GMM_TEXTURE_INFO *pTexInfo)
+{
+    GMM_STATUS Status = GMM_SUCCESS;
+
+    if((pTexInfo->MSAA.NumSamples == 2) || (pTexInfo->MSAA.NumSamples == 4))
+    {
+        pTexInfo->BitsPerPixel = 8;
+        pTexInfo->Format       = GMM_FORMAT_R8_UINT;
+    }
+    else if(pTexInfo->MSAA.NumSamples == 8)
+    {
+        pTexInfo->BitsPerPixel = 32;
+        pTexInfo->Format       = GMM_FORMAT_R32_UINT;
+    }
+    else //if(pTexInfo->MSAA.NumSamples == 16)
+    {
+        pTexInfo->BitsPerPixel = 64;
+        pTexInfo->Format       = GMM_FORMAT_GENERIC_64BIT;
+    }
+
+    if((Status = __GmmTexFillHAlignVAlign(pTexInfo)) != GMM_SUCCESS) // Need to get our alignment (matching RT) before overwriting our RT's MSAA setting.
+    {
+        return Status;
+    }
+    pTexInfo->MSAA.NumSamples         = 1; // CCS itself isn't MSAA'ed.
+    pTexInfo->Flags.Gpu.__MsaaTileMcs = 1;
+
+    return Status;
+}
+
+/////////////////////////////////////////////////////////////////////////////////////
+///Allocate one memory tile wider than is required for Media Memory Compression
+///
+/// @param[in]  See function definition.
+///
+/// @return     ::
+/////////////////////////////////////////////////////////////////////////////////////
+void GMM_STDCALL GmmLib::GmmTextureCalc::AllocateOneTileThanRequied(GMM_TEXTURE_INFO *pTexInfo,
+                                                                    GMM_GFX_SIZE_T &  WidthBytesRender,
+                                                                    GMM_GFX_SIZE_T &  WidthBytesPhysical,
+                                                                    GMM_GFX_SIZE_T &  WidthBytesLock)
+{
+    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
+
+    if(pTexInfo->Flags.Gpu.MMC && !pTexInfo->Flags.Gpu.UnifiedAuxSurface)
+    {
+        WidthBytesRender += pPlatform->TileInfo[pTexInfo->TileMode].LogicalTileWidth;
+        WidthBytesPhysical = WidthBytesLock = WidthBytesRender;
+    }
+}
