@@ -60,7 +60,12 @@ static inline int _BitScanForward(uint32_t *index, uint32_t mask)
 {
     int i;
 
+#ifdef __ANDROID__
+    i = ffs(mask);
+#else
     i = ffsl(mask);
+#endif
+
     if(i > 0)
     {
         *index = (uint32_t)(i - 1);
