@@ -72,6 +72,10 @@ extern const SWIZZLE_DESCRIPTOR INTEL_64KB_UNDEFINED_64_128bpp;
 #define GMM_NO_FENCE_REG        0xDEADBEEF
 #define GMM_MAX_DISPLAYS        3
 
+#if defined __linux__
+typedef void* HANDLE;
+#endif
+
 //===========================================================================
 // typedef:
 //      GMM_GFX_ADDRESS/etc.
@@ -196,6 +200,20 @@ typedef enum GMM_TILE_TYPE_ENUM
     GMM_NOT_TILED
 }GMM_TILE_TYPE;
 
+//===========================================================================
+// typedef:
+//     GMM_E2E_COMPRESSION_TYPE_ENUM
+//
+// Description:
+//     This enum details compression type (i.e. render or media compressed, or uncompressed )
+//---------------------------------------------------------------------------
+typedef enum GMM_E2E_COMPRESSION_TYPE_ENUM
+{
+    GMM_UNCOMPRESSED,
+    GMM_RENDER_COMPRESSED,
+    GMM_MEDIA_COMPRESSED
+}GMM_E2E_COMPRESSION_TYPE;
+
 //===========================================================================
 // typedef:
 //     GMM_CPU_CACHE_TYPE_ENUM
@@ -416,6 +434,70 @@ typedef enum GMM_SURFACESTATE_FORMAT_ENUM
     #include "GmmFormatTable.h"
 } GMM_SURFACESTATE_FORMAT;
 
+typedef enum GMM_E2ECOMP_FORMAT_ENUM
+{
+    GMM_E2ECOMP_FORMAT_INVALID = 0,
+    GMM_E2ECOMP_FORMAT_RGB64,       //1h - Reserved
+    GMM_E2ECOMP_FORMAT_RGB32,       //2h - Reserved
+
+    GMM_E2ECOMP_MIN_FORMAT = GMM_E2ECOMP_FORMAT_RGB32,
+
+    GMM_E2ECOMP_FORMAT_YUY2,       //3h
+    GMM_E2ECOMP_FORMAT_YCRCB_SWAPUV = GMM_E2ECOMP_FORMAT_YUY2,
+    GMM_E2ECOMP_FORMAT_YCRCB_SWAPUVY = GMM_E2ECOMP_FORMAT_YUY2,
+    GMM_E2ECOMP_FORMAT_YCRCB_SWAPY = GMM_E2ECOMP_FORMAT_YUY2,
+
+    GMM_E2ECOMP_FORMAT_Y410,       //4h
+
+    GMM_E2ECOMP_FORMAT_Y210,       //5h
+    GMM_E2ECOMP_FORMAT_Y216 = GMM_E2ECOMP_FORMAT_Y210,
+
+    GMM_E2ECOMP_FORMAT_Y416,       //6h
+    GMM_E2ECOMP_FORMAT_P010,       //7h
+    GMM_E2ECOMP_FORMAT_P016,       //8h
+    GMM_E2ECOMP_FORMAT_AYUV,       //9h
+
+    GMM_E2ECOMP_FORMAT_ARGB8b,     //Ah
+    GMM_E2ECOMP_FORMAT_RGB5A1 = GMM_E2ECOMP_FORMAT_ARGB8b,
+    GMM_E2ECOMP_FORMAT_RGBA4 = GMM_E2ECOMP_FORMAT_ARGB8b,
+    GMM_E2ECOMP_FORMAT_B5G6R5 = GMM_E2ECOMP_FORMAT_ARGB8b,
+
+    GMM_E2ECOMP_FORMAT_SWAPY,      //Bh
+    GMM_E2ECOMP_FORMAT_SWAPUV,     //Ch
+    GMM_E2ECOMP_FORMAT_SWAPUVY,    //Dh
+    GMM_E2ECOMP_FORMAT_RGB10b,     //Eh  --Which media format is it?
+    GMM_E2ECOMP_FORMAT_NV12,       //Fh
+
+    GMM_E2ECOMP_FORMAT_RGBAFLOAT16,            //0x10h
+
+    GMM_E2ECOMP_FORMAT_R32G32B32A32_FLOAT,     //0x11h
+    GMM_E2ECOMP_FORMAT_R32G32B32A32_SINT,      //0x12h
+    GMM_E2ECOMP_FORMAT_R32G32B32A32_UINT,      //0x13h
+    GMM_E2ECOMP_FORMAT_R16G16B16A16_UNORM,     //0x14h
+    GMM_E2ECOMP_FORMAT_R16G16B16A16_SNORM,     //0x15h
+    GMM_E2ECOMP_FORMAT_R16G16B16A16_SINT,      //0x16h
+    GMM_E2ECOMP_FORMAT_R16G16B16A16_UINT,      //0x17h
+
+    GMM_E2ECOMP_FORMAT_R10G10B10A2_UNORM,      //0x18h
+    GMM_E2ECOMP_FORMAT_RGB10A2 = GMM_E2ECOMP_FORMAT_R10G10B10A2_UNORM,
+
+    GMM_E2ECOMP_FORMAT_R10G10B10FLOAT_A2_UNORM,    //0x19h
+    GMM_E2ECOMP_FORMAT_R10G10B10A2_UINT,       //0x1Ah
+    GMM_E2ECOMP_FORMAT_R8G8B8A8_SNORM,         //0x1Bh
+    GMM_E2ECOMP_FORMAT_R8G8B8A8_SINT,          //0x1Ch
+    GMM_E2ECOMP_FORMAT_R8G8B8A8_UINT,          //0x1Dh
+
+    GMM_E2ECOMP_FORMAT_R11G11B10_FLOAT,        //0x1Eh
+    GMM_E2ECOMP_FORMAT_RG11B10 = GMM_E2ECOMP_FORMAT_R11G11B10_FLOAT,
+
+    GMM_E2ECOMP_MAX_FORMAT = GMM_E2ECOMP_FORMAT_R11G11B10_FLOAT,    //should always be equal to last format encoding
+
+    GMM_E2ECOMP_FORMAT_RGBA = GMM_E2ECOMP_FORMAT_INVALID,
+    GMM_E2ECOMP_FORMAT_R = GMM_E2ECOMP_FORMAT_INVALID,
+    GMM_E2ECOMP_FORMAT_RG = GMM_E2ECOMP_FORMAT_INVALID,
+
+} GMM_E2ECOMP_FORMAT;
+
 //===========================================================================
 // typedef:
 //     GMM_TILE_WALK
