@@ -85,43 +85,34 @@ namespace GmmLib
             /* Function prototypes */
             GMM_VIRTUAL bool                IsPresentableformat();
             // Move GMM Restrictions to it's own class?
-            GMM_VIRTUAL void                GetGenericRestrictions(__GMM_BUFFER_TYPE *pBuff);
-            GMM_VIRTUAL __GMM_BUFFER_TYPE*  GetBestRestrictions(__GMM_BUFFER_TYPE *pFirstBuffer, const __GMM_BUFFER_TYPE *pSecondBuffer);
             virtual bool        CopyClientParams(GMM_RESCREATE_PARAMS &CreateParams);
             GMM_VIRTUAL bool                RedescribePlanes();
             GMM_VIRTUAL bool                ReAdjustPlaneProperties(bool IsAuxSurf);
             GMM_VIRTUAL const GMM_PLATFORM_INFO& GetPlatformInfo();
 
-            /* Inline functions */
             /////////////////////////////////////////////////////////////////////////////////////
-            /// Checks where the restrictions are invalid or not
-            /// @param[in]  pRestriction Restrictions to check
-            /// @return     true if restriction is invalid. false otherwise.
+            /// Returns tile mode for SURFACE_STATE programming.
+            /// @return     Tiled Mode
             /////////////////////////////////////////////////////////////////////////////////////
-            GMM_INLINE_VIRTUAL GMM_INLINE bool IsRestrictionInvalid(__GMM_BUFFER_TYPE *pRestriction)
+            GMM_INLINE uint32_t GetTileModeSurfaceState(const GMM_TEXTURE_INFO *pTextureInfo) const
             {
-                return ((pRestriction->MinDepth == 0xffffffff) ? true : false);
+                uint32_t TiledMode = 0;
+
+                if(GMM_IS_TILEY)
+                {
+                    TiledMode =
+                        pTextureInfo->Flags.Info.Linear ? 0 :
+                            pTextureInfo->Flags.Info.TiledW ? 1 :
+                            pTextureInfo->Flags.Info.TiledX ? 2 :
+                            /* Y/YF/YS */ 3;
+
+                    __GMM_ASSERT((TiledMode != 3) || (pTextureInfo->Flags.Info.TiledY || pTextureInfo->Flags.Info.TiledYf || pTextureInfo->Flags.Info.TiledYs));
+                }
+
+                return TiledMode;
             }
 
-            /////////////////////////////////////////////////////////////////////////////////////
-            /// Returns restrictions for a linear buffer.
-            /// @param[out]     pBuff Restrictions are returned in this buffer
-            /////////////////////////////////////////////////////////////////////////////////////
-            GMM_INLINE_VIRTUAL GMM_INLINE void GetLinearRestrictions(__GMM_BUFFER_TYPE* pBuff)
-            {
-                *pBuff = GMM_OVERRIDE_PLATFORM_INFO(&Surf)->Linear;
-            }
-
-            /////////////////////////////////////////////////////////////////////////////////////
-            /// Returns restrictions for the primary buffer.
-            /// @param[out]     pBuff Restrictions are returned in this buffer
-            /////////////////////////////////////////////////////////////////////////////////////
-            GMM_INLINE_VIRTUAL GMM_INLINE void GetPrimaryRestrictions(__GMM_BUFFER_TYPE* pBuff)
-            {
-                *pBuff = GMM_OVERRIDE_PLATFORM_INFO(&Surf)->ASyncFlipSurface;
-            }
-
-        public:
+    public:
             /* Constructors */
             GmmResourceInfoCommon():
                 ClientType(),
@@ -169,6 +160,7 @@ namespace GmmLib
                 ClientType          = rhs.ClientType;
                 Surf                = rhs.Surf;
                 AuxSurf             = rhs.AuxSurf;
+                AuxSecSurf          = rhs.AuxSecSurf;
                 RotateInfo          = rhs.RotateInfo;
                 ExistingSysMem      = rhs.ExistingSysMem;
                 SvmAddress          = rhs.SvmAddress;
@@ -203,6 +195,7 @@ namespace GmmLib
             GMM_VIRTUAL void                    GMM_STDCALL GetTiledResourceMipPacking(uint32_t *pNumPackedMips,
                                                                            uint32_t *pNumTilesForPackedMips);
             GMM_VIRTUAL uint32_t                GMM_STDCALL GetPackedMipTailStartLod();
+            GMM_VIRTUAL bool                    GMM_STDCALL IsMipRCCAligned(uint8_t &MisAlignedLod);
             GMM_VIRTUAL uint8_t                 GMM_STDCALL GetDisplayFastClearSupport();
             GMM_VIRTUAL uint8_t                 GMM_STDCALL GetDisplayCompressionSupport();
             GMM_VIRTUAL uint32_t                GMM_STDCALL GetCompressionBlockWidth();
@@ -931,6 +924,40 @@ namespace GmmLib
                 }
             };
 
+            /////////////////////////////////////////////////////////////////////////////////////
+            /// Returns size of the surface depending on the surface parameters.
+            /// @return     Size of surface
+            ///
+            /// Below legacy API to query surface size are deprecated and will be removed in
+            /// later gmm releases. Client must move to unified GetSize() api.
+            ///  - GmmResGetSizeSurface()/ pResInfo->GetSizeSurface()
+            ///  - GmmResGetSizeMainSurface()/  pResInfo->GetSizeAllocation()
+            ///  - GmmResGetSizeAllocation()/ pResInfo->GetSizeMainSurface()
+            /////////////////////////////////////////////////////////////////////////////////////
+            GMM_INLINE_VIRTUAL GMM_INLINE_EXPORTED GMM_GFX_SIZE_T  GMM_STDCALL GetSize(GMM_SIZE_PARAM GmmSizeParam)
+            {
+                GMM_GFX_SIZE_T Size = 0;
+                switch (GmmSizeParam)
+                {
+                    case GMM_MAIN_SURF:
+                        Size =  Surf.Size;
+                        break;
+                    case GMM_MAIN_PLUS_AUX_SURF:
+                        Size =  Surf.Size + AuxSurf.Size + AuxSecSurf.Size;
+                        break;
+                    case GMM_TOTAL_SURF:
+                        Size = Surf.Size + AuxSurf.Size + AuxSecSurf.Size;
+                        if (Is64KBPageSuitable())
+                        {
+                            Size = GFX_ALIGN(Surf.Size + AuxSurf.Size + AuxSecSurf.Size, GMM_KBYTE(64));
+                        }
+                        break;
+                    default:
+                        __GMM_ASSERT(0);
+                }
+                return Size;
+            }
+
             /////////////////////////////////////////////////////////////////////////////////////
             /// Returns size of the main surface only. Aux surface size not included.
             /// @return     Size of main surface
@@ -958,10 +985,9 @@ namespace GmmLib
             /////////////////////////////////////////////////////////////////////////////////////
             GMM_INLINE_VIRTUAL GMM_INLINE_EXPORTED GMM_GFX_SIZE_T  GMM_STDCALL GetSizeAllocation()
             {
-                #define ALIGN_SIZE(x, a)  (((x) + ((a) - 1)) - (((x) + ((a) - 1)) & ((a) - 1)))
                 if (Is64KBPageSuitable())
-                {
-                    return(ALIGN_SIZE(Surf.Size + AuxSurf.Size + AuxSecSurf.Size, GMM_KBYTE(64)));
+                { 
+                    return(GFX_ALIGN(Surf.Size + AuxSurf.Size + AuxSecSurf.Size, GMM_KBYTE(64)));
                 }
                 else
                 {
@@ -1285,16 +1311,19 @@ namespace GmmLib
                 {
                     if (GetResFlags().Info.TiledYf || GMM_IS_64KB_TILE(GetResFlags()))
                     {
-                        HAlign = 0;
+                        HAlign = 1; //Ignored, but we'll retrun valid encoding nonetheless.
                     }
                     else
                     {
-                        switch (GetHAlign())
+                        if(GMM_IS_TILEY)
                         {
-                            case 4:  HAlign = 1; break;
-                            case 8:  HAlign = 2; break;
-                            case 16: HAlign = 3; break;
-                            default: HAlign = 0; __GMM_ASSERT(0);
+                            switch (GetHAlign())
+                            {
+                                case 4:  HAlign = 1; break;
+                                case 8:  HAlign = 2; break;
+                                case 16: HAlign = 3; break;
+                                default: HAlign = 1; // TODO(Benign): Change back to 0 + assert after packed YUV handling corrected.
+                            }
                         }
                     }
                 }
@@ -1326,7 +1355,7 @@ namespace GmmLib
                 {
                     if (GetResFlags().Info.TiledYf || GMM_IS_64KB_TILE(GetResFlags()))
                     {
-                        VAlign = 0;
+                        VAlign = 1; // Ignored , but we'll return valid encoding nonetheless.
                     }
                     else
                     {
@@ -1335,7 +1364,7 @@ namespace GmmLib
                             case 4:  VAlign = 1; break;
                             case 8:  VAlign = 2; break;
                             case 16: VAlign = 3; break;
-                            default: VAlign = 0; __GMM_ASSERT(0);
+                            default: VAlign = 1;
                         }
                     }
                 }
@@ -1359,16 +1388,16 @@ namespace GmmLib
             /////////////////////////////////////////////////////////////////////////////////////
             GMM_INLINE_VIRTUAL GMM_INLINE_EXPORTED uint32_t GMM_STDCALL GetTileModeSurfaceState()
             {
-                uint32_t   TiledMode = 0;
-
-                TiledMode =
-                    Surf.Flags.Info.Linear ? 0 :
-                        Surf.Flags.Info.TiledX ? 2 :
-                        /* Y/YF/YS */       3;
-
-                __GMM_ASSERT((TiledMode != 3) || (Surf.Flags.Info.TiledY || Surf.Flags.Info.TiledYf || Surf.Flags.Info.TiledYs));
-
-                return TiledMode;
+                return GetTileModeSurfaceState(&Surf);
+			}
+			
+			/////////////////////////////////////////////////////////////////////////////////////
+            /// Returns tile mode for AUX SURFACE_STATE programming.
+            /// @return     Tiled Mode
+            /////////////////////////////////////////////////////////////////////////////////////
+            GMM_INLINE_VIRTUAL GMM_INLINE_EXPORTED uint32_t GMM_STDCALL GetAuxTileModeSurfaceState()
+            {
+                return GetTileModeSurfaceState(&AuxSurf);
             }
 
             /////////////////////////////////////////////////////////////////////////////////////
