@@ -181,7 +181,9 @@ typedef struct GMM_RESOURCE_ALIGNMENT_REC
 // TBD - Place holder for GMM_RESOURCE_FLAG definition.
 //---------------------------------------------------------------------------
 #include "GmmResourceFlags.h"
-
+#if defined __linux__
+    #include "External/Linux/GmmResourceInfoLinExt.h"
+#endif
 
 //==========================================================================
 // typedef:
@@ -349,6 +351,34 @@ typedef enum
     GMM_AUX_SURF    // Total Aux Surface (CCS + CC + Padding)
 } GMM_UNIFIED_AUX_TYPE;
 
+//===========================================================================
+// enum :
+//        GMM_SIZE_PARAM
+//
+// Description:
+//     This enumarates various surface size parameters available for GetSize query.
+//     Refer GmmResourceInfoCommon.h  GetSize() api
+//
+//     Note:
+//     Below legacy API to query surface size are deprecated and will be removed in
+//     later gmm releases.
+//     - GmmResGetSizeSurface()/ pResInfo->GetSizeSurface()
+//     - GmmResGetSizeMainSurface()/  pResInfo->GetSizeAllocation()
+//     - GmmResGetSizeAllocation()/ pResInfo->GetSizeMainSurface()
+//---------------------------------------------------------------------------
+// Usage :
+//     UMD client use this enum to request the surface size.
+//===========================================================================
+typedef enum
+{
+    GMM_INVALID_PARAM,       // Leave 0 as invalid to force client to explictly set
+    GMM_MAIN_SURF,           // Main surface size(w/o aux data)
+    GMM_MAIN_PLUS_AUX_SURF,  // Main surface plus auxilary data, includes ccs, cc, zcs, mcs metadata. Renderable portion of the surface.
+    GMM_TOTAL_SURF,          // Main+Aux with additional padding based on hardware PageSize.
+    GMM_MAPGPUVA_SIZE = GMM_TOTAL_SURF,// To be used for mapping gpu virtual address space.
+} GMM_SIZE_PARAM;
+
+
 //===========================================================================
 // typedef:
 //        GMM_RES_COPY_BLT
@@ -441,6 +471,7 @@ uint8_t             GMM_STDCALL GmmIsP0xx(GMM_RESOURCE_FORMAT Format);
 uint8_t             GMM_STDCALL GmmIsUVPacked(GMM_RESOURCE_FORMAT Format);
 bool                GMM_STDCALL GmmIsYUVFormatLCUAligned(GMM_RESOURCE_FORMAT Format);
 #define                         GmmIsYUVPlanar GmmIsPlanar // TODO(Benign): Support old name until we have a chance to correct in UMD(s) using this. No longer YUV since there are now RGB planar formats.
+uint8_t             GMM_STDCALL GmmIsReconstructableSurface(GMM_RESOURCE_FORMAT Format);
 uint8_t             GMM_STDCALL GmmIsCompressed(GMM_RESOURCE_FORMAT Format);
 uint8_t             GMM_STDCALL GmmIsYUVPacked(GMM_RESOURCE_FORMAT Format);
 uint8_t             GMM_STDCALL GmmIsRedecribedPlanes(GMM_RESOURCE_INFO *pGmmResource);
